'use strict';

var vue = require('vue');

function useCounter(initialValue = 0) {
    const count = vue.ref(initialValue);
    const increment = () => count.value++;
    const decrement = () => count.value--;
    const reset = () => (count.value = initialValue);
    return {
        count,
        increment,
        decrement,
        reset,
    };
}

// src/constants/chineseCalendar.ts
// 天干数组（元组类型）
const TIAN_GAN = [
    "甲", "乙", "丙", "丁", "戊", "己", "庚", "辛", "壬", "癸"
];
// 地支数组（元组类型）
const DI_ZHI = [
    "子", "丑", "寅", "卯", "辰", "巳", "午", "未", "申", "酉", "戌", "亥"
];
// 五鼠遁口诀映射表（使用Record类型）
const ZI_SHIGAN_MAP = {
    甲: 0, 己: 0,
    乙: 2, 庚: 2,
    丙: 4, 辛: 4,
    丁: 6, 壬: 6,
    戊: 8, 癸: 8,
};
/**
 * 五鼠遁算法实现
 * @param dayGanZhi 日天干地支（如"甲子"）
 * @param currentShiChen 当前时辰（可选），不填则返回子时
 * @throws 参数不合法时抛出错误
 */
function useWuShuDun(dayGanZhi, currentShiChen) {
    const result = {
        allGanZhi: [],
        currentGanZhi: ""
    };
    // 参数校验（增强类型安全）
    if (!/^[甲乙丙丁戊己庚辛壬癸][子丑寅卯辰巳午未申酉戌亥]$/.test(dayGanZhi)) {
        throw new Error('输入格式错误，请输入有效的日天干地支（如"甲子"）');
    }
    // 提取日天干
    const dayGan = dayGanZhi[0];
    // 获取起始索引（类型安全访问）
    const startIndex = ZI_SHIGAN_MAP[dayGan] ?? (() => {
        throw new Error("无效的天干输入，请输入合法天干");
    })();
    // 生成十二时辰干支（优化为Array.from）
    result.allGanZhi = Array.from({ length: DI_ZHI.length }, (_, index) => {
        const ganIndex = (startIndex + index) % TIAN_GAN.length;
        return `${TIAN_GAN[ganIndex]}${DI_ZHI[index]}`;
    });
    // 处理当前时辰（使用空值合并运算符）
    const shiChen = currentShiChen ?? "子";
    const shiChenIndex = DI_ZHI.indexOf(shiChen);
    // 确保索引有效性（类型断言）
    result.currentGanZhi = result.allGanZhi[shiChenIndex >= 0 ? shiChenIndex : 0];
    return result;
}

exports.DI_ZHI = DI_ZHI;
exports.TIAN_GAN = TIAN_GAN;
exports.useCounter = useCounter;
exports.useWuShuDun = useWuShuDun;
